pr def income_shock0
    args option
quietly {
// 0 - Income differentiation for labor participants and non-participants

// 2 - Simulate income shock of employed vs unemployed based on statistics of a previous ESI year
// Var lists for Income by employment status in each year
local vl_ie0 "unemployed constant"
local vl_ie1 "unemployed sexo zona2 tr_edad2 educ quintile_renta"
local vl_ie2 "unemployed sexo zona2 sector_ind tr_edad2 educ quintile_renta"
local vl_ie3 "unemployed sexo zona2 actividad tr_edad educ quintile_renta"
local vl_ie4 "unemployed sexo zona2 quintile_renta"

// 2.1 - Import Income according to the simulated employment status in this year
foreach i of numlist 2 1 4 { // Import Income of labor-participants
*foreach i of numlist 2 { // Import Income of labor-participants
capture drop _merge 
local var_list = "year `vl_ie`i''"
*joinby `var_list' using "$path2b\emp_ing_ocup_x`i'.dta", update unmatched(master)
joinby `var_list' using "$path2b\emp_ing_ocup2_x`i'.dta", update unmatched(master)
local var_list = "`vl_ie`i''"  
linear_reg_impute replacement_ratio "`var_list'"
sum replacement_ratio if replacement_ratio>0 & replacement_ratio<1
replace replacement_ratio=r(min) if replacement_ratio<=0
replace replacement_ratio=r(max) if replacement_ratio>=1 & replacement_ratio<.
foreach x of varlist ing_tot_o* ln_ing_tot_o* sd_ln_ing_tot_o* sd_ing_tot_o* replacement_r* {
linear_reg_impute `x' "`var_list'"
sum `x' if `x'>0.0001
replace `x'=r(min) if `x'<=0.0001
}
}
//
rename replacement_ratio rr_inc
rename sd_ln_ing_tot_ocup sd_ln_inc
rename sd_ing_tot_ocup sd_inc

// Intermediate inputs - I assume sh_inc was created in layoff_jobfind0 or layoff_jobfind
foreach var_inc in rr_inc sd_ln_inc sd_inc {
g `var_inc'_w0 = `var_inc'*sh_inc 
bysort folio: egen `var_inc'2_w = total(`var_inc'_w0)

g `var_inc'2_hh0 =  `var_inc' if a2==1 
g `var_inc'2_i0 =  `var_inc' if a1==1 
bysort folio: egen `var_inc'2_hh = mean(`var_inc'2_hh0)
bysort folio: egen `var_inc'2_i = mean(`var_inc'2_i0)

if `option'==1 { // Layoff and job-find probability is a income share weighted household average
// if no income use the household head probability, if no household head use the interviewed probability
g `var_inc'_sect = `var_inc'2_w*aux_`var_inc'
replace `var_inc'_sect = `var_inc'2_hh*aux_`var_inc'_hh if `var_inc'_sect==.
replace `var_inc'_sect = `var_inc'2_i*aux_`var_inc'_i if `var_inc'_sect==.
replace `var_inc'_sect = 0 if `var_inc'_sect==.
}
//

if `option'==2 { // Layoff and job-find probability is the household head probability, 
// if no household head use the interviewed probability, if not use the income share weighted household average
g `var_inc'_sect = `var_inc'2_hh*aux_`var_inc'_hh 
replace `var_inc'_sect = `var_inc'2_i*aux_`var_inc'_i if `var_inc'_sect==.
replace `var_inc'_sect = `var_inc'2_w*aux_`var_inc' if `var_inc'_sect==.
replace `var_inc'_sect = 0 if `var_inc'_sect==.
}
//

// 2 - These options have a layoff and jobfind probability for everyone (not just employed or unemployed)
if `option'==12 { // Layoff and job-find probability is a income share weighted household average
// if no income use the household head probability, if no household head use the interviewed probability
g `var_inc'_sect = `var_inc'2_w
replace `var_inc'_sect = `var_inc'2_hh if `var_inc'_sect==.
replace `var_inc'_sect = `var_inc'2_i if `var_inc'_sect==.
replace `var_inc'_sect = 0 if `var_inc'_sect==.
}
//

if `option'==22 { // Layoff and job-find probability is the household head probability, 
// if no household head use the interviewed probability, if not use the income share weighted household average
g `var_inc'_sect = `var_inc'2_hh 
replace `var_inc'_sect = `var_inc'2_i if `var_inc'_sect==.
replace `var_inc'_sect = `var_inc'2_w if `var_inc'_sect==.
replace `var_inc'_sect = 0 if `var_inc'_sect==.
}
}

}
//
end
